@@ -14,7 +14,7 @@ BOOTSTRAP_PY=$(find "${PWD}" -name bootstrap.py -type f)
 DEPS_FILTER=$(find "${PWD}" -name deps-tarball-filter.txt -type f)
 
 # Download cargo tarballs
-uscan --rename --force-download --destdir ${TMPDIR}
+uscan --rename --download-current-version --destdir ${TMPDIR}
 
 # Download crates.io-index snapshotted for this cargo 
 . debian/crates.io-index
